pub enum Location {
SrcPos {
src: Source,
pos: SourcePosition,
},
Fused {
metadata: Option<AttrObj>,
locations: Vec<Location>,
},
Named {
name: String,
child_loc: Box<Location>,
},
CallSite {
callee: Box<Location>,
caller: Box<Location>,
},
Unknown,
}Expand description
Represents a (combination of) program source locations. This captures more or less the functionality of MLIR’s BuiltinLocationAttributes. For simplicity, unlike in MLIR, Location is not extensible.
Variants
SrcPos
A Source along with a position within it. This is same as MLIR’s FileLineColLoc.
Fused
A collection of other source locations. This is same as MLIR’s FusedLoc.
Named
Location with a name. See NameLoc.
CallSite
Connects the location of a callee with the location of the caller. See CallSiteLoc.
Unknown
Location unknown. See UnknownLoc.
Implementations